@@ -10,9 +10,11 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::AUTHORITY = 'cpan:TOBYINK';
-	$Type::Params::VERSION   = '1.005_004';
+	$Type::Params::VERSION   = '1.007_000';
 }
 
+$Type::Params::VERSION =~ tr/_//d;
+
 use B qw();
 use Eval::TypeTiny;
 use Scalar::Util qw(refaddr);
@@ -248,6 +250,10 @@ sub compile
 			);
 			$varname = '$tmp'.($is_optional ? '{x}' : '');
 		}
+
+		# unweaken the constraint in the cache
+		undef $Type::Tiny::ALL_TYPES{ $constraint->{uniq} };
+		$Type::Tiny::ALL_TYPES{ $constraint->{uniq} } = $constraint;
 		
 		if ($constraint->can_be_inlined)
 		{
@@ -281,7 +287,7 @@ sub compile
 			push @code, sprintf 'push @R, %s;', $varname;
 		}
 	}
-	
+		
 	if ($min_args == $max_args and not $saw_slurpy)
 	{
 		$code[1] = sprintf(
