@@ -11,10 +11,12 @@ BEGIN {
 
 BEGIN {
 	$Type::Tiny::AUTHORITY   = 'cpan:TOBYINK';
-	$Type::Tiny::VERSION     = '1.005_004';
+	$Type::Tiny::VERSION     = '1.007_000';
 	$Type::Tiny::XS_VERSION  = '0.011';
 }
 
+$Type::Tiny::XS_VERSION =~ tr/_//d;
+
 use Scalar::Util qw( blessed );
 use Types::TypeTiny ();
 
@@ -892,69 +894,79 @@ sub is_parameterized
 	shift->has_parameters;
 }
 
-my %param_cache;
-sub parameterize
 {
-	my $self = shift;
-	
-	$self->is_parameterizable
-		or @_ ? _croak("Type '%s' does not accept parameters", "$self") : return($self);
-	
-	@_ = map Types::TypeTiny::to_TypeTiny($_), @_;
+	my %seen;
+	sub ____make_key {
+		join ',', map {
+			Types::TypeTiny::TypeTiny->check($_) ? sprintf('$Type::Tiny::ALL_TYPES{%d}', $_->{uniq}) :
+			ref() eq 'ARRAY'                     ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('[%s]', ____make_key(@$_)) } :
+			ref() eq 'HASH'                      ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('{%s}', ____make_key(%$_)) } :
+			ref() eq 'SCALAR' || ref() eq 'REF'  ? do { $seen{$_}++ ? '____CANNOT_KEY____' : sprintf('do { my $x = %s; \\$x }', ____make_key($$_)) } :
+			!defined()                           ? 'undef' :
+			!ref()                               ? do { require B; B::perlstring($_) } :
+			'____CANNOT_KEY____';
+		} @_;
+	}
+	my %param_cache;
+	sub parameterize
+	{
+		my $self = shift;
+		
+		$self->is_parameterizable
+			or @_ ? _croak("Type '%s' does not accept parameters", "$self") : return($self);
+		
+		@_ = map Types::TypeTiny::to_TypeTiny($_), @_;
 
-	# Generate a key for caching parameterized type constraints,
-	# but only if all the parameters are strings or type constraints.
-	my $key;
-	if ( not grep(ref($_) && !Types::TypeTiny::TypeTiny->check($_), @_) )
-	{
-		require B;
-		$key = join ":", map(Types::TypeTiny::TypeTiny->check($_) ? $_->{uniq} : B::perlstring($_), $self, @_);
-	}
-	
-	return $param_cache{$key} if defined $key && defined $param_cache{$key};
-	
-	local $Type::Tiny::parameterize_type = $self;
-	local $_ = $_[0];
-	my $P;
-	
-	my ($constraint, $compiled) = $self->constraint_generator->(@_);
-	
-	if (Types::TypeTiny::TypeTiny->check($constraint))
-	{
-		$P = $constraint;
-	}
-	else
-	{
-		my %options = (
-			constraint   => $constraint,
-			display_name => $self->name_generator->($self, @_),
-			parameters   => [@_],
-		);
-		$options{compiled_type_constraint} = $compiled
-			if $compiled;
-		$options{inlined} = $self->inline_generator->(@_)
-			if $self->has_inline_generator;
-		exists $options{$_} && !defined $options{$_} && delete $options{$_}
-			for keys %options;
+		# Generate a key for caching parameterized type constraints,
+		# but only if all the parameters are strings or type constraints.
+		%seen = ();
+		my $key = $self->____make_key(@_);
+		undef($key) if $key =~ /____CANNOT_KEY____/;
+		return $param_cache{$key} if defined $key && defined $param_cache{$key};
 		
-		$P = $self->create_child_type(%options);
+		local $Type::Tiny::parameterize_type = $self;
+		local $_ = $_[0];
+		my $P;
 		
-		my $coercion;
-		$coercion = $self->coercion_generator->($self, $P, @_)
-			if $self->has_coercion_generator;
-		$P->coercion->add_type_coercions( @{$coercion->type_coercion_map} )
-			if $coercion;
+		my ($constraint, $compiled) = $self->constraint_generator->(@_);
+		
+		if (Types::TypeTiny::TypeTiny->check($constraint))
+		{
+			$P = $constraint;
+		}
+		else
+		{
+			my %options = (
+				constraint   => $constraint,
+				display_name => $self->name_generator->($self, @_),
+				parameters   => [@_],
+			);
+			$options{compiled_type_constraint} = $compiled
+				if $compiled;
+			$options{inlined} = $self->inline_generator->(@_)
+				if $self->has_inline_generator;
+			exists $options{$_} && !defined $options{$_} && delete $options{$_}
+				for keys %options;
+			
+			$P = $self->create_child_type(%options);
+			
+			my $coercion;
+			$coercion = $self->coercion_generator->($self, $P, @_)
+				if $self->has_coercion_generator;
+			$P->coercion->add_type_coercions( @{$coercion->type_coercion_map} )
+				if $coercion;
+		}
+		
+		if (defined $key)
+		{
+			$param_cache{$key} = $P;
+			Scalar::Util::weaken($param_cache{$key});
+		}
+		
+		$P->coercion->freeze;
+		
+		return $P;
 	}
-	
-	if (defined $key)
-	{
-		$param_cache{$key} = $P;
-		Scalar::Util::weaken($param_cache{$key});
-	}
-	
-	$P->coercion->freeze;
-	
-	return $P;
 }
 
 sub child_type_class
@@ -965,7 +977,9 @@ sub child_type_class
 sub create_child_type
 {
 	my $self = shift;
-	return $self->child_type_class->new(parent => $self, @_);
+	my %moreopts;
+	$moreopts{is_object} = 1 if $self->{is_object};
+	return $self->child_type_class->new(parent => $self, %moreopts, @_);
 }
 
 sub complementary_type
@@ -1204,6 +1218,8 @@ sub _lookup_my_method
 	return;
 }
 
+my %object_methods = (with_attribute_values => 1, stringifies_to => 1, numifies_to => 1);
+
 sub can
 {
 	my $self = shift;
@@ -1226,6 +1242,11 @@ sub can
 			return $method if $method;
 		}
 	}
+
+	if ($self->{is_object} && $object_methods{$_[0]}) {
+		require Type::Tiny::ConstrainedObject;
+		return Type::Tiny::ConstrainedObject->can($_[0]);
+	}
 	
 	return;
 }
@@ -1250,6 +1271,12 @@ sub AUTOLOAD
 		}
 	}
 	
+	if ($self->{is_object} && $object_methods{$m}) {
+		require Type::Tiny::ConstrainedObject;
+		unshift @_, $self;
+		goto( Type::Tiny::ConstrainedObject->can($m) );
+	}
+	
 	_croak q[Can't locate object method "%s" via package "%s"], $m, ref($self)||$self;
 }
 
@@ -1272,68 +1299,6 @@ sub _has_xsub
 sub of                         { shift->parameterize(@_) }
 sub where                      { shift->create_child_type(constraint => @_) }
 
-{
-	my $i = 0;
-	my $_where_expressions = sub {
-		my $self = shift;
-		my $name = shift;
-		$name ||= "where expression check";
-		my (%env, @codes);
-		while (@_) {
-			my $expr       = shift;
-			my $constraint = shift;
-			if (!ref $constraint) {
-				push @codes, sprintf('do { local $_ = %s; %s }', $expr, $constraint);
-			}
-			else {
-				my $type = Types::TypeTiny::to_TypeTiny($constraint);
-				if ($type->can_be_inlined) {
-					push @codes, sprintf('do { my $tmp = %s; %s }', $expr, $type->inline_check('$tmp'));
-				}
-				else {
-					++$i;
-					$env{'$chk'.$i} = do { my $chk = $type->compiled_check; \$chk };
-					push @codes, sprintf('$chk%d->(%s)', $i, $expr);
-				}
-			}
-		}
-		
-		if (keys %env) {
-			# cannot inline
-			my $sub = Eval::TypeTiny::eval_closure(
-				source      => sprintf('sub ($) { local $_ = shift; %s }', join(q( and ), @codes)),
-				description => sprintf('%s for %s', $name, $self->name),
-				environment => \%env,
-			);
-			return $self->where($sub);
-		}
-		else {
-			return $self->where(join(q( and ), @codes));
-		}
-	};
-	
-	sub stringifies_as {
-		my $self         = shift;
-		my ($constraint) = @_;
-		$self->$_where_expressions("stringification check", q{"$_"}, $constraint);
-	}
-	
-	sub numifies_as {
-		my $self         = shift;
-		my ($constraint) = @_;
-		$self->$_where_expressions("numification check", q{0+$_}, $constraint);
-	}
-	
-	sub attributes_as {
-		my $self         = shift;
-		my ($constraint) = @_;
-		$self->$_where_expressions(
-			"attributes check",
-			map { my $attr = $_; qq{\$_->$attr} => $constraint->{$attr} } sort keys %$constraint
-		);
-	}
-}
-
 # fill out Moose-compatible API
 sub inline_environment         { +{} }
 sub _inline_check              { shift->inline_check(@_) }
@@ -1344,6 +1309,8 @@ sub _actually_compile_type_constraint   { shift->_build_compiled_check }
 sub hand_optimized_type_constraint      { shift->{hand_optimized_type_constraint} }
 sub has_hand_optimized_type_constraint  { exists(shift->{hand_optimized_type_constraint}) }
 sub type_parameter             { (shift->parameters || [])->[0] }
+sub parameterized_from         { $_[0]->is_parameterized ? shift->parent : _croak("Not a parameterized type") }
+sub has_parameterized_from     { $_[0]->is_parameterized }
 
 # some stuff for Mouse-compatible API
 sub __is_parameterized         { shift->is_parameterized(@_) }
@@ -1654,6 +1621,10 @@ Returns true iff the type constraint does not have a C<name>.
 Indicates whether a type has been parameterized (e.g. C<< ArrayRef[Int] >>)
 or could potentially be (e.g. C<< ArrayRef >>).
 
+=item C<< has_parameterized_from >>
+
+Useless alias for C<is_parameterized>.
+
 =back
 
 =head3 Validation and coercion
@@ -1855,6 +1826,11 @@ L</"Attributes related to parameterizable and parameterized types">
 documents the C<parameters> attribute, which returns an arrayref of all
 the parameters.
 
+=item C<< parameterized_from >>
+
+Harder to spell alias for C<parent> that only works for parameterized
+types.
+
 =back
 
 B<< Hint for people subclassing Type::Tiny: >>
@@ -2098,6 +2074,11 @@ L<Mouse::Meta::TypeConstraint>.
 
 L<Type::Params>.
 
+L<Type::Tiny on GitHub|https://github.com/tobyink/p5-type-tiny>,
+L<Type::Tiny on Travis-CI|https://travis-ci.org/tobyink/p5-type-tiny>,
+L<Type::Tiny on AppVeyor|https://ci.appveyor.com/project/tobyink/p5-type-tiny>,
+L<Type::Tiny on Coveralls|https://coveralls.io/github/tobyink/p5-type-tiny>.
+
 =head1 AUTHOR
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
