@@ -6,23 +6,23 @@ use warnings;
 
 BEGIN {
 	$Type::Tiny::Duck::AUTHORITY = 'cpan:TOBYINK';
-	$Type::Tiny::Duck::VERSION   = '1.005_004';
+	$Type::Tiny::Duck::VERSION   = '1.007_000';
 }
 
+$Type::Tiny::Duck::VERSION =~ tr/_//d;
+
 use Scalar::Util qw< blessed >;
 
 sub _croak ($;@) { require Error::TypeTiny; goto \&Error::TypeTiny::croak }
 
-use Type::Tiny ();
-our @ISA = 'Type::Tiny';
+require Type::Tiny::ConstrainedObject;
+our @ISA = 'Type::Tiny::ConstrainedObject';
+sub _short_name { 'Duck' }
 
 sub new {
 	my $proto = shift;
 	
 	my %opts = (@_==1) ? %{$_[0]} : @_;
-	_croak "Duck type constraints cannot have a parent constraint passed to the constructor" if exists $opts{parent};
-	_croak "Duck type constraints cannot have a constraint coderef passed to the constructor" if exists $opts{constraint};
-	_croak "Duck type constraints cannot have a inlining coderef passed to the constructor" if exists $opts{inlined};
 	_croak "Need to supply list of methods" unless exists $opts{methods};
 	
 	$opts{methods} = [$opts{methods}] unless ref $opts{methods};
@@ -93,17 +93,6 @@ sub _instantiate_moose_type
 	return "Moose::Meta::TypeConstraint::DuckType"->new(%opts, methods => $self->methods);
 }
 
-sub has_parent
-{
-	!!1;
-}
-
-sub parent
-{
-	require Types::Standard;
-	Types::Standard::Object();
-}
-
 sub validate_explain
 {
 	my $self = shift;
@@ -202,6 +191,24 @@ constructor.
 
 =back
 
+=head2 Methods
+
+=over
+
+=item C<< stringifies_to($constraint) >>
+
+See L<Type::Tiny::ConstrainedObject>.
+
+=item C<< numifies_to($constraint) >>
+
+See L<Type::Tiny::ConstrainedObject>.
+
+=item C<< with_attribute_values($attr1 => $constraint1, ...) >>
+
+See L<Type::Tiny::ConstrainedObject>.
+
+=back
+
 =head1 BUGS
 
 Please report any bugs to
