@@ -6,9 +6,11 @@ use warnings;
 
 BEGIN {
 	$Type::Tiny::Intersection::AUTHORITY = 'cpan:TOBYINK';
-	$Type::Tiny::Intersection::VERSION   = '1.005_004';
+	$Type::Tiny::Intersection::VERSION   = '1.007_000';
 }
 
+$Type::Tiny::Intersection::VERSION =~ tr/_//d;
+
 use Scalar::Util qw< blessed >;
 use Types::TypeTiny ();
 
@@ -149,6 +151,36 @@ sub validate_explain
 	return;  # uncoverable statement
 }
 
+my $_delegate = sub {
+	my ($self, $method) = (shift, shift);
+	my @types = @{ $self->type_constraints };
+	my $found = 0;
+	for my $i (0 .. $#types) {
+		my $type = $types[$i];
+		if ($type->can($method)) {
+			$types[$i] = $type->$method(@_);
+			++$found;
+			last;
+		}
+	}
+	_croak('Could not apply method %s to any type within the intersection', $method) unless $found;
+	ref($self)->new(type_constraints => \@types);
+};
+
+sub stringifies_to {
+	my $self = shift;
+	$self->$_delegate(stringifies_to => @_);
+}
+
+sub numifies_to {
+	my $self = shift;
+	$self->$_delegate(numifies_to => @_);
+}
+
+sub with_attribute_values {
+	my $self = shift;
+	$self->$_delegate(with_attribute_values => @_);
+}
 
 my $comparator;
 $comparator = sub {
@@ -235,6 +267,24 @@ parent type; we choose the first arbitrarily.)
 
 =back
 
+=head2 Methods
+
+=over
+
+=item C<< stringifies_to($constraint) >>
+
+See L<Type::Tiny::ConstrainedObject>.
+
+=item C<< numifies_to($constraint) >>
+
+See L<Type::Tiny::ConstrainedObject>.
+
+=item C<< with_attribute_values($attr1 => $constraint1, ...) >>
+
+See L<Type::Tiny::ConstrainedObject>.
+
+=back
+
 =head2 Overloading
 
 =over
