@@ -12,9 +12,11 @@ BEGIN {
 
 BEGIN {
 	$Types::Standard::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Standard::VERSION   = '1.005_004';
+	$Types::Standard::VERSION   = '1.007_000';
 }
 
+$Types::Standard::VERSION =~ tr/_//d;
+
 use Type::Library -base;
 
 our @EXPORT_OK = qw( slurpy );
@@ -23,30 +25,37 @@ use Scalar::Util qw( blessed looks_like_number );
 use Type::Tiny ();
 use Types::TypeTiny ();
 
+my $is_class_loaded;
+
 BEGIN {
+	$is_class_loaded = q{sub {
+		return !!0 if ref $_[0];
+		return !!0 if not $_[0];
+		my $stash = do { no strict 'refs'; \%{"$_[0]\::"} };
+		return !!1 if exists $stash->{'ISA'};
+		return !!1 if exists $stash->{'VERSION'};
+		foreach my $globref (values %$stash) {
+			return !!1
+				if ref \$globref eq 'GLOB'
+					? *{$globref}{CODE}
+					: ref $globref; # const or sub ref
+		}
+		return !!0;
+	}};
+	
 	*_is_class_loaded = Type::Tiny::_USE_XS
 		? \&Type::Tiny::XS::Util::is_class_loaded
-		: sub {
-			return !!0 if ref $_[0];
-			return !!0 if not $_[0];
-			my $stash = do { no strict 'refs'; \%{"$_[0]\::"} };
-			return !!1 if exists $stash->{'ISA'};
-			return !!1 if exists $stash->{'VERSION'};
-			foreach my $globref (values %$stash) {
-				return !!1
-					if ref \$globref eq 'GLOB'
-						? *{$globref}{CODE}
-						: ref $globref; # const or sub ref
-			}
-			return !!0;
-		};
+		: eval $is_class_loaded;
+	
+	*_AVOID_CALLBACKS = $ENV{'PERL_TYPE_TINY_AVOID_CALLBACKS'}
+		? sub () { 1 }
+		: sub () { 0 };
+	
+	*_USE_RUXS = !_AVOID_CALLBACKS() && eval { require Ref::Util::XS; Ref::Util::XS::->VERSION(0.100); 1; }
+		? sub () { !!1 }
+		: sub () { !!0 };
 };
 
-my $HAS_RUXS = eval {
-	require Ref::Util::XS;
-	Ref::Util::XS::->VERSION(0.100);
-	1;
-};
 
 my $add_core_type = sub {
 	my $meta = shift;
@@ -90,7 +99,9 @@ my $add_core_type = sub {
 	$typedef->{compiled_type_constraint} = $xsub if $xsub;
 	
 	$typedef->{inlined} = sub { "$xsubname\($_[1])" }
-		if defined($xsubname) and (
+		if  !_AVOID_CALLBACKS
+		and defined($xsubname)
+		and (
 			# These should be faster than their normal inlined
 			# equivalents
 			$name eq 'Str' or
@@ -269,14 +280,22 @@ my $_classn = $meta->add_type({
 	name       => "ClassName",
 	parent     => $_str,
 	constraint => \&_is_class_loaded,
-	inlined    => sub { "Types::Standard::_is_class_loaded(do { my \$tmp = $_[1] })" },
+	inlined    => sub {
+		_AVOID_CALLBACKS
+			? "($is_class_loaded)->(do { my \$tmp = $_[1] })"
+			: "Types::Standard::_is_class_loaded(do { my \$tmp = $_[1] })"
+	},
 });
 
 $meta->add_type({
 	name       => "RoleName",
 	parent     => $_classn,
 	constraint => sub { not $_->can("new") },
-	inlined    => sub { "Types::Standard::_is_class_loaded(do { my \$tmp = $_[1] }) and not $_[1]\->can('new')" },
+	inlined    => sub {
+		_AVOID_CALLBACKS
+			? "($is_class_loaded)->(do { my \$tmp = $_[1] }) and not $_[1]\->can('new')"
+			: "Types::Standard::_is_class_loaded(do { my \$tmp = $_[1] }) and not $_[1]\->can('new')"
+	},
 });
 
 my $_ref = $meta->$add_core_type({
@@ -322,7 +341,7 @@ $meta->$add_core_type({
 	name       => "CodeRef",
 	parent     => $_ref,
 	constraint => sub { ref $_ eq "CODE" },
-	inlined    => $HAS_RUXS
+	inlined    => _USE_RUXS
 		? sub { "Ref::Util::XS::is_plain_coderef($_[1])" }
 		: sub { "ref($_[1]) eq 'CODE'" },
 });
@@ -338,7 +357,7 @@ $meta->$add_core_type({
 	name       => "GlobRef",
 	parent     => $_ref,
 	constraint => sub { ref $_ eq "GLOB" },
-	inlined    => $HAS_RUXS
+	inlined    => _USE_RUXS
 		? sub { "Ref::Util::XS::is_plain_globref($_[1])" }
 		: sub { "ref($_[1]) eq 'GLOB'" },
 });
@@ -360,7 +379,7 @@ my $_arr = $meta->$add_core_type({
 	name       => "ArrayRef",
 	parent     => $_ref,
 	constraint => sub { ref $_ eq "ARRAY" },
-	inlined    => $HAS_RUXS
+	inlined    => _USE_RUXS
 		? sub { "Ref::Util::XS::is_plain_arrayref($_[1])" }
 		: sub { "ref($_[1]) eq 'ARRAY'" },
 	constraint_generator => LazyLoad(ArrayRef => 'constraint_generator'),
@@ -373,7 +392,7 @@ my $_hash = $meta->$add_core_type({
 	name       => "HashRef",
 	parent     => $_ref,
 	constraint => sub { ref $_ eq "HASH" },
-	inlined    => $HAS_RUXS
+	inlined    => _USE_RUXS
 		? sub { "Ref::Util::XS::is_plain_hashref($_[1])" }
 		: sub { "ref($_[1]) eq 'HASH'" },
 	constraint_generator => LazyLoad(HashRef => 'constraint_generator'),
@@ -401,9 +420,10 @@ my $_obj = $meta->$add_core_type({
 	name       => "Object",
 	parent     => $_ref,
 	constraint => sub { blessed $_ },
-	inlined    => $HAS_RUXS
+	inlined    => _USE_RUXS
 		? sub { "Ref::Util::XS::is_blessed_ref($_[1])" }
 		: sub { "Scalar::Util::blessed($_[1])" },
+	is_object  => 1,
 });
 
 $meta->$add_core_type({
@@ -622,6 +642,7 @@ $meta->add_type({
 				map "overload::Method($v, q[$_])", @operations;
 		};
 	},
+	is_object  => 1,
 });
 
 $meta->add_type({
@@ -1313,6 +1334,18 @@ If C<PERL_TYPE_TINY_XS> does not exist, can be set to true to suppress XS
 usage similarly. (Several other CPAN distributions also pay attention to this
 environment variable.)
 
+=item C<PERL_TYPE_TINY_AVOID_CALLBACKS>
+
+Tells Types::Standard that when generating inlined code, this code should
+avoid calling any functions except Perl built-ins, L<re>, L<overload>,
+and L<Scalar::Util>. This might be useful if you want to store the generated
+code and run it on a machine that might not have Type::Tiny installed, or run
+it without loading Type::Tiny into memory. It's for things like L<Mite> and
+L<Mo> (which are both pretty dead projects, but the idea is interesting).
+This currently only affects StrMatch, ClassName, and RoleName. Other types
+in this library don't make any callbacks to other functions anyway. Many
+of the types in L<Types::TypeTiny> do though.
+
 =back
 
 =begin private
