@@ -6,9 +6,11 @@ use warnings;
 
 BEGIN {
 	$Types::Standard::StrMatch::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Standard::StrMatch::VERSION   = '1.005_004';
+	$Types::Standard::StrMatch::VERSION   = '1.007_000';
 }
 
+$Types::Standard::StrMatch::VERSION =~ tr/_//d;
+
 use Type::Tiny ();
 use Types::Standard ();
 use Types::TypeTiny ();
@@ -32,7 +34,7 @@ my $serialize_regexp = sub {
 		$serialized = eval { Regexp::Util::serialize_regexp($re) };
 	}
 	
-	if (!$serialized) {
+	unless (Types::Standard::_AVOID_CALLBACKS or defined $serialized) {
 		my $key = sprintf('%s|%s', ref($re), $re);
 		$expressions{$key} = $re;
 		$serialized = sprintf('$Types::Standard::StrMatch::expressions{%s}', B::perlstring($key));
@@ -75,11 +77,12 @@ sub __inline_generator
 {
 	require B;
 	my ($regexp, $checker) = @_;
+	my $serialized_re = $regexp->$serialize_regexp or return;
+	
 	if ($checker)
 	{
 		return unless $checker->can_be_inlined;
 		
-		my $serialized_re = $regexp->$serialize_regexp;
 		return sub
 		{
 			my $v = $_[1];
@@ -103,7 +106,6 @@ sub __inline_generator
 			return sub { "!ref($_) and length($_)==$length" };
 		}
 		
-		my $serialized_re = $regexp->$serialize_regexp;
 		return sub
 		{
 			my $v = $_[1];
